# Generated by Django 3.1.6 on 2021-02-19 14:40

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('mlmtools', '0006_auto_20210219_1421'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='marketernode',
            name='node_cut',
        ),
        migrations.RemoveField(
            model_name='marketernode',
            name='sub_cut',
        ),
        migrations.AddField(
            model_name='marketernode',
            name='split_cut',
            field=models.DecimalField(decimal_places=2, default=100.0, help_text='% of split between this one and sub nodes', max_digits=5),
        ),
    ]
