# Generated by Django 3.1.6 on 2021-02-20 17:44

from django.db import migrations, models
import django.db.models.deletion
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [
        ('mlmtools', '0007_auto_20210219_1440'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='trackcode',
            name='owner',
        ),
        migrations.AddField(
            model_name='trackcode',
            name='created_at',
            field=models.DateTimeField(auto_now_add=True, default=django.utils.timezone.now),
            preserve_default=False,
        ),
        migrations.AddField(
            model_name='trackcode',
            name='discount',
            field=models.DecimalField(decimal_places=2, default=10, max_digits=5),
        ),
        migrations.AddField(
            model_name='trackcode',
            name='discount_type',
            field=models.CharField(choices=[('perc', '%'), ('CZK', 'CZK')], default='perc', max_length=4, verbose_name='dt'),
        ),
        migrations.AddField(
            model_name='trackcode',
            name='node',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, to='mlmtools.marketernode'),
        ),
        migrations.AddField(
            model_name='trackcode',
            name='usage',
            field=models.CharField(choices=[('always', 'always'), ('useronce', 'once per user'), ('once', 'once only')], default='useronce', max_length=8),
        ),
        migrations.AddField(
            model_name='trackcode',
            name='valid_from',
            field=models.DateField(null=True),
        ),
        migrations.AddField(
            model_name='trackcode',
            name='valid_until',
            field=models.DateField(null=True),
        ),
        migrations.AlterField(
            model_name='marketernode',
            name='split_cut',
            field=models.DecimalField(decimal_places=2, default=100.0, help_text='% of split between THIS one and other', max_digits=5),
        ),
        migrations.AlterField(
            model_name='marketernode',
            name='split_type',
            field=models.CharField(choices=[('fixed', 'fixed'), ('treesplit', 'tree split')], default='fixed', help_text='How to split, fixed amount (1 level), or tree split (recursively sent up the tree)', max_length=16),
        ),
    ]
