# Generated by Django 3.2.2 on 2021-05-13 09:55

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('mlmtools', '0009_auto_20210305_1743'),
    ]

    operations = [
        migrations.CreateModel(
            name='DummyTarget',
            fields=[
                ('id', models.AutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=2048)),
                ('amount', models.DecimalField(decimal_places=2, max_digits=5)),
            ],
        ),
    ]
