# Generated by Django 3.2.2 on 2021-11-12 10:16

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('mlmtools', '0011_alter_dummytarget_amount'),
    ]

    operations = [
        migrations.AlterField(
            model_name='codeuse',
            name='amount',
            field=models.DecimalField(decimal_places=2, default=10, max_digits=10),
        ),
    ]
