# Generated by Django 3.2.3 on 2022-09-02 12:28

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('mlmtools', '0012_alter_codeuse_amount'),
    ]

    operations = [
        migrations.AddField(
            model_name='trackcode',
            name='max_n',
            field=models.PositiveIntegerField(default=1, help_text='The maximum number of codes applied to usage choices'),
        ),
        migrations.AlterField(
            model_name='trackcode',
            name='usage',
            field=models.CharField(choices=[('always', 'always'), ('useronce', 'Nx / user'), ('once', 'Nx / user')], default='useronce', max_length=8),
        ),
    ]
